@@ -46,7 +46,7 @@ class PhotosLibrary:
         return run_script("_photoslibrary_isrunning")
 
     def hide(self):
-        """ Tell Photos to hide it's window """
+        """ Tell Photos to hide its window """
         run_script("_photoslibrary_hide")
 
     @property
@@ -407,7 +407,7 @@ class PhotosLibrary:
             timeout: number of seconds to wait for Photos to complete export before timing out; default = 120
         
         Returns:
-            full paths of exported photos.  There may be more than one photo exported due 
+            List of full paths of exported photos.  There may be more than one photo exported due 
             to live images and burst images.
         
         Raises:
@@ -475,7 +475,7 @@ class Album:
             else:
                 uuid = uuid.split("/")[0]
 
-        valuuidalbum = run_script("_album_exists", uuid)
+        valuuidalbum = run_script("_album_exists", id_)
         if valuuidalbum:
             self.id = id_
             self._uuid = uuid
@@ -581,10 +581,10 @@ class Album:
             export_path: path to export to
             original: if True, export original image, otherwise export current image; default = False
             overwrite: if True, export will overwrite a file of same name as photo in export_path; default = False
-            timeout: number of seconds to wait for Photos to complete export before timing out; default = 120
+            timeout: number of seconds to wait for Photos to complete export (for each photo) before timing out; default = 120
         
         Returns:
-            full paths of exported photos.  There may be more than one photo exported due 
+            List of full paths of exported photos.  There may be more than one photo exported due 
             to live images and burst images.
         
         Raises:
@@ -622,7 +622,7 @@ class Album:
         new_album = photoslib.create_album(
             photoslib._temp_album_name(), folder=self.parent
         )
-        old_photos = self.photos
+        old_photos = self.photos()
         new_photo_uuids = [
             photo.id for photo in old_photos if photo.id not in photo_ids
         ]
@@ -657,10 +657,19 @@ class Album:
 
 class Folder:
     def __init__(self, uuid):
-        valid_folder = run_script("_folder_exists", uuid)
+        id_ = uuid
+        # check to see if we need to add UUID suffix
+        if float(PhotosLibrary().version) >= 5.0:
+            if len(uuid.split("/")) == 1:
+                # osxphotos style UUID without the suffix
+                id_ = f"{uuid}{UUID_SUFFIX_FOLDER}"
+            else:
+                uuid = uuid.split("/")[0]
+        
+        valid_folder = run_script("_folder_exists", id_)
         if valid_folder:
-            self.id = uuid
-            self._uuid = uuid.split("/")[0]
+            self.id = id_ 
+            self._uuid = uuid
         else:
             raise ValueError(f"Invalid folder id: {uuid}")
 
@@ -934,7 +943,7 @@ class Photo:
             timeout: number of seconds to wait for Photos to complete export before timing out; default = 120
         
         Returns:
-            full paths of exported photos.  There may be more than one photo exported due 
+            List of full paths of exported photos.  There may be more than one photo exported due 
             to live images and burst images.
         
         Raises:
